@@ -5,8 +5,7 @@
 #   All rights reserved. Copyright (c) 2016 VECTIONEER.
 #
 
-from motorcortex.request import Request, ConnectionState
-from motorcortex.request import Reply
+from motorcortex.request import Request, Reply, ConnectionState
 from motorcortex.subscription import Subscription
 from pynng import Sub0, TLSConfig
 from concurrent.futures import ThreadPoolExecutor
@@ -15,7 +14,7 @@ from queue import Queue
 
 class Subscribe:
     """Subscribe class is used to receive continuous parameter updates from motorcortex server.
-    
+
         Subscribe class simplifies creating and removing subscription groups.
 
         Args:
@@ -85,12 +84,6 @@ class Subscribe:
         return Reply(self.__pool.submit(Request.waitForConnection, self.__connected_lock,
                                         conn_timeout_ms / 1000.0))
 
-    def resubscribe(self):
-        print("resubscribe")
-        for _, s in self.__subscriptions.items():
-            print(f"resubscribe: {s}")
-            self.__req.createGroup(s.layout(), s.alias(), s.frqDivider())
-
     def close(self):
         """Close connection to the server"""
         self.__connection_state = ConnectionState.DISCONNECTING
@@ -151,7 +144,7 @@ class Subscribe:
 
         """
         sub_id = subscription.id()
-        sub_id_buf = bytes([sub_id & 0xff, (sub_id >> 8) & 0xff, (sub_id >> 16) & 0xff])
+        sub_id_buf = Subscribe.__idBuf(subscription.id())
 
         # stop receiving sub
         try:
@@ -172,8 +165,28 @@ class Subscribe:
     def connectionState(self):
         return self.__connection_state
 
+    def resubscribe(self):
+        old_sub = self.__subscriptions.copy()
+        self.__subscriptions.clear()
+        for i in old_sub:
+            s = old_sub[i]
+            try:
+                # unsubscribe from the old group
+                self.__socket.unsubscribe(Subscribe.__idBuf(s.id()))
+            except:
+                pass
+            # subscribe again, update id
+            msg = self.__req.createGroup(s.layout(), s.alias(), s.frqDivider()).get()
+            s._updateId(msg.id)
+            self.__socket.subscribe(Subscribe.__idBuf(s.id()))
+            self.__subscriptions[s.id()] = s
+
+    @staticmethod
+    def __idBuf(msg_id):
+        return bytes([msg_id & 0xff, (msg_id >> 8) & 0xff, (msg_id >> 16) & 0xff])
+
     def __complete(self, msg, subscription, socket):
         if subscription._complete(msg):
-            id_buf = bytes([msg.id & 0xff, (msg.id >> 8) & 0xff, (msg.id >> 16) & 0xff])
+            id_buf = Subscribe.__idBuf(msg.id)
             socket.subscribe(id_buf)
             self.__subscriptions[msg.id] = subscription
