@@ -83,6 +83,7 @@ class OpenSubscribeConnection(unittest.TestCase):
         sub.close()
         req.close()
 
+
 class Reconnection(unittest.TestCase):
 
     def stateChange(self, req, sub, state):
@@ -96,6 +97,10 @@ class Reconnection(unittest.TestCase):
             print("connection lost")
         if state == motorcortex.ConnectionState.DISCONNECTED:
             print(f"disconnected")
+
+    def notify(self, x):
+        print(x)
+
     def test(self):
         # Open subscribe connection
         # Creating empty object for parameter tree
@@ -109,10 +114,8 @@ class Reconnection(unittest.TestCase):
                                        certificate="mcx.cert.pem", timeout_ms=5000,
                                        login="root", password="vectioneer")
 
-
-        sub.subscribe(["root/Comm_task/actual_cycle_max"], "test").notify(lambda x : print(x))
-
-
+        sub.subscribe(["root/Comm_task/actual_cycle_max"], "test", 2000).notify(lambda x: print(f"1:{x}"))
+        sub.subscribe(["root/Comm_task/actual_cycle_max"], "test1", 2000).notify(lambda x: print(f"2:{x}"))
         time.sleep(10000)
         sub.close()
         req.close()
